==> inventorio-mc1.20.6-fabric-v1.11.0-sources.jar: de/rubixdev/inventorio/mixin/client/InGameHudMixinLP.java <==
package de.rubixdev.inventorio.mixin.client;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import de.rubixdev.inventorio.client.ui.HotbarHUDRenderer;
import de.rubixdev.inventorio.player.PlayerInventoryAddon;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_329;
import net.minecraft.class_332;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

//#if MC >= 12101
//$$ import net.minecraft.client.render.RenderTickCounter;
//#endif

@Mixin(value = class_329.class, priority = 99)
@Environment(EnvType.CLIENT)
public class InGameHudMixinLP {
    /**
     * This mixin redirects rendering the hotbar itself in case Segmented Hotbar
     * is selected.
     */
    @Inject(method = "renderHotbar", at = @At(value = "HEAD"), cancellable = true, require = 0)
    private void inventorioRenderSegmentedHotbar(/* #if <- hack around formatter */
        class_332 context,
        //#if MC >= 12101
        //$$ RenderTickCounter tickCounter,
        //#else
        float tickDelta,
        //#endif
        CallbackInfo ci
    ) {
        if (HotbarHUDRenderer.INSTANCE.renderSegmentedHotbar(context)) ci.cancel();
    }

    @Inject(method = "renderHotbar", at = @At(value = "RETURN"), require = 0)
    private void inventorioRenderFunctionOnlySelector(/* #if <- hack around formatter */
        class_332 context,
        //#if MC >= 12101
        //$$ RenderTickCounter tickCounter,
        //#else
        float tickDelta,
        //#endif
        CallbackInfo ci
    ) {
        HotbarHUDRenderer.INSTANCE.renderFunctionOnlySelector(context);
    }

    /**
     * In vanilla, when you look at an entity with a sword, it shows an attack
     * indicator. This mixin restores this feature if you have a sword in your
     * tool belt.
     */
    @ModifyExpressionValue(
        method = "renderCrosshair",
        at = @At(
            value = "INVOKE",
            target = "Lnet/minecraft/client/network/ClientPlayerEntity;getAttackCooldownProgressPerTick()F"
        ),
        require = 0
    )
    private float inventorioShowAttackIndicator(float original) {
        PlayerInventoryAddon addon = PlayerInventoryAddon.Client.INSTANCE.getLocal();
        if (addon != null && !addon.findFittingToolBeltStack(new class_1799(class_1802.field_8802)).isEmpty())
            return 20.0f;
        return original;
    }
}

==> inventorio-mc1.21.1-fabric-v1.11.0-sources.jar: de/rubixdev/inventorio/mixin/client/InGameHudMixinLP.java <==
package de.rubixdev.inventorio.mixin.client;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import de.rubixdev.inventorio.client.ui.HotbarHUDRenderer;
import de.rubixdev.inventorio.player.PlayerInventoryAddon;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_329;
import net.minecraft.class_332;
import net.minecraft.class_9779;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(value = class_329.class, priority = 99)
@Environment(EnvType.CLIENT)
public class InGameHudMixinLP {
    /**
     * This mixin redirects rendering the hotbar itself in case Segmented Hotbar
     * is selected.
     */
    @Inject(method = "renderHotbar", at = @At(value = "HEAD"), cancellable = true, require = 0)
    private void inventorioRenderSegmentedHotbar(/* #if <- hack around formatter */
        class_332 context,
        //#if MC >= 12101
        class_9779 tickCounter,
        //#else
        //$$ float tickDelta,
        //#endif
        CallbackInfo ci
    ) {
        if (HotbarHUDRenderer.INSTANCE.renderSegmentedHotbar(context)) ci.cancel();
    }

    @Inject(method = "renderHotbar", at = @At(value = "RETURN"), require = 0)
    private void inventorioRenderFunctionOnlySelector(/* #if <- hack around formatter */
        class_332 context,
        //#if MC >= 12101
        class_9779 tickCounter,
        //#else
        //$$ float tickDelta,
        //#endif
        CallbackInfo ci
    ) {
        HotbarHUDRenderer.INSTANCE.renderFunctionOnlySelector(context);
    }

    /**
     * In vanilla, when you look at an entity with a sword, it shows an attack
     * indicator. This mixin restores this feature if you have a sword in your
     * tool belt.
     */
    @ModifyExpressionValue(
        method = "renderCrosshair",
        at = @At(
            value = "INVOKE",
            target = "Lnet/minecraft/client/network/ClientPlayerEntity;getAttackCooldownProgressPerTick()F"
        ),
        require = 0
    )
    private float inventorioShowAttackIndicator(float original) {
        PlayerInventoryAddon addon = PlayerInventoryAddon.Client.INSTANCE.getLocal();
        if (addon != null && !addon.findFittingToolBeltStack(new class_1799(class_1802.field_8802)).isEmpty())
            return 20.0f;
        return original;
    }
}
